sqlobject.inheritance.tests.test\_asdict module
===============================================

.. automodule:: sqlobject.inheritance.tests.test_asdict
    :members:
    :undoc-members:
    :show-inheritance:
